==> haskell-criterion-measurement-0.1.1.0-48-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion-measurement
version: 0.1.1.0
id: criterion-measurement-0.1.1.0-3pPvXeEdv6NFLRX6MlVEaM
key: criterion-measurement-0.1.1.0-3pPvXeEdv6NFLRX6MlVEaM
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/criterion
synopsis: Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.
category: Development, Performance, Testing, Benchmarking
abi: 0e724931a37c19cb2b11229f65e572dc
exposed: True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-measurement-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-measurement-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/criterion-measurement-0.1.1.0
hs-libraries: HScriterion-measurement-0.1.1.0-3pPvXeEdv6NFLRX6MlVEaM
depends:
    aeson-1.4.3.0-3QzK2ng22UC3SLyLfNCRqk base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr binary-0.8.6.0
    containers-0.6.0.1 deepseq-1.4.4.0
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock
haddock-html: /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-measurement-0.1.1.0-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion-measurement
version: 0.1.1.0
id: criterion-measurement-0.1.1.0-61jQo4PHwyKJAGaJmOZygc
key: criterion-measurement-0.1.1.0-61jQo4PHwyKJAGaJmOZygc
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/criterion
synopsis: Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.
category: Development, Performance, Testing, Benchmarking
abi: a8f72fb6662f648581bde5d3b81b87e9
exposed: True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-measurement-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-measurement-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/criterion-measurement-0.1.1.0
hs-libraries: HScriterion-measurement-0.1.1.0-61jQo4PHwyKJAGaJmOZygc
depends:
    aeson-1.4.4.0-8EzwlpxsJYiJGXz8JVXZ1i base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr binary-0.8.6.0
    containers-0.6.0.1 deepseq-1.4.4.0
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock
haddock-html: /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
